"""HTTP API service layer for Flock.

This module contains HTTP service implementations and API models for
serving the Flock orchestrator over HTTP with REST endpoints.
"""

from flock.api.base_service import BaseHTTPService


__all__ = ["BaseHTTPService"]
