"""Module for Tracing ServerComponent."""

from flock.components.server.traces.trace_component import (
    TracingComponent,
    TracingComponentConfig,
)


__all__ = [
    "TracingComponent",
    "TracingComponentConfig",
]
