"""CORS-ServerComponent Module."""

from flock.components.server.cors.cors_component import (
    CORSComponent,
    CORSComponentConfig,
    RouteSpecificCORSConfig,
)


__all__ = [
    "CORSComponent",
    "CORSComponentConfig",
    "RouteSpecificCORSConfig",
]
