"""Module for AgentsServerComponent and associated classes."""

from flock.components.server.agents.agents_component import (
    AgentsServerComponent,
    AgentsServerComponentConfig,
)


__all__ = [
    "AgentsServerComponent",
    "AgentsServerComponentConfig",
]
