"""Module for static-files ServerComponent."""

from flock.components.server.static_files.static_files import (
    StaticFilesComponentConfig,
    StaticFilesServerComponent,
)


__all__ = [
    "StaticFilesComponentConfig",
    "StaticFilesServerComponent",
]
