"""Module for WebSocketServerComponent."""

from flock.components.server.websocket.websocket_component import (
    WebSocketComponentConfig,
    WebSocketServerComponent,
)


__all__ = [
    "WebSocketComponentConfig",
    "WebSocketServerComponent",
]
